@@ -14,11 +14,16 @@
 #import <CommonCrypto/CommonDigest.h>
 #import "UIDevice+SpeedCategory.h"
 #import "VLCBugreporter.h"
-#import <MediaPlayer/MediaPlayer.h>
+
+#import "OBSlider.h"
+#import "VLCStatusLabel.h"
+#import "VLCHorizontalSwipeGestureRecognizer.h"
+#import "VLCVerticalSwipeGestureRecognizer.h"
 
 #define INPUT_RATE_DEFAULT  1000.
 
-@interface VLCMovieViewController () <UIGestureRecognizerDelegate, AVAudioSessionDelegate>
+@interface VLCMovieViewController () <UIGestureRecognizerDelegate, AVAudioSessionDelegate,
+                                    VLCHorizontalSwipeGestureRecognizer, VLCVerticalSwipeGestureRecognizer>
 {
     VLCMediaPlayer *_mediaPlayer;
 
@@ -189,7 +194,7 @@
     [self.view addGestureRecognizer:downSwipeRecognizer];
 #endif
 
-    _aspectRatios = @[@"DEFAULT", @"4:3", @"16:9", @"16:10", @"2.21:1", @"FILL_TO_SCREEN"];
+    _aspectRatios = @[@"DEFAULT", @"FILL_TO_SCREEN", @"4:3", @"16:9", @"16:10", @"2.21:1"];
 
     [self.aspectRatioButton setBackgroundImage:[UIImage imageNamed:@"ratioButton"] forState:UIControlStateNormal];
     [self.aspectRatioButton setBackgroundImage:[UIImage imageNamed:@"ratioButtonHighlight"] forState:UIControlStateHighlighted];
@@ -284,6 +289,7 @@
 
     NSUserDefaults *defaults = [NSUserDefaults standardUserDefaults];
 
+    _mediaPlayer = nil;
     _mediaPlayer = [[VLCMediaPlayer alloc] initWithOptions:@[[NSString stringWithFormat:@"--%@=%@", kVLCSettingSubtitlesFont, [defaults objectForKey:kVLCSettingSubtitlesFont]], [NSString stringWithFormat:@"--%@=%@", kVLCSettingSubtitlesFontColor, [defaults objectForKey:kVLCSettingSubtitlesFontColor]], [NSString stringWithFormat:@"--%@=%@", kVLCSettingSubtitlesFontSize, [defaults objectForKey:kVLCSettingSubtitlesFontSize]], [NSString stringWithFormat:@"--%@=%@", kVLCSettingDeinterlace, [defaults objectForKey:kVLCSettingDeinterlace]]]];
     [_mediaPlayer setDelegate:self];
     [_mediaPlayer setDrawable:self.movieView];
@@ -411,8 +417,13 @@
         if (self.mediaItem.duration.intValue != 0)
             playbackPositionInTime = @(self.mediaItem.lastPosition.floatValue * (self.mediaItem.duration.intValue / 1000.));
     }
-    [_mediaPlayer.media addOptions:@{@"start-time": playbackPositionInTime}];
-    APLog(@"set starttime to %i", playbackPositionInTime.intValue);
+    if (playbackPositionInTime.intValue > 0) {
+        [_mediaPlayer.media addOptions:@{@"start-time": playbackPositionInTime}];
+        APLog(@"set starttime to %i", playbackPositionInTime.intValue);
+    }
+
+    [_mediaPlayer addObserver:self forKeyPath:@"time" options:0 context:nil];
+    [_mediaPlayer addObserver:self forKeyPath:@"remainingTime" options:0 context:nil];
 
     [_mediaPlayer play];
 
@@ -460,10 +471,17 @@
 - (void)_stopPlayback
 {
     if (_mediaPlayer) {
+        @try {
+            [_mediaPlayer removeObserver:self forKeyPath:@"time"];
+            [_mediaPlayer removeObserver:self forKeyPath:@"remainingTime"];
+        }
+        @catch (NSException *exception) {
+            APLog(@"we weren't an observer yet");
+        }
+
         [_mediaPlayer pause];
         [self _saveCurrentState];
         [_mediaPlayer stop];
-        _mediaPlayer = nil; // save memory and some CPU time
     }
     if (_mediaItem)
         _mediaItem = nil;
@@ -692,7 +710,8 @@
     [self _resetIdleTimer];
 }
 
-- (void)mediaPlayerTimeChanged:(NSNotification *)aNotification {
+- (void)observeValueForKeyPath:(NSString *)keyPath ofObject:(id)object change:(NSDictionary *)change context:(void *)context
+{
     if (!_isScrubbing) {
         self.positionSlider.value = [_mediaPlayer position];
     }
