@@ -9,27 +9,23 @@
 //
 
 #import <UIKit/UIKit.h>
-#import "AQGridView.h"
 
 #define EXPERIMENTAL_LIBRARY 1
 
-#define kVLCLibraryModeAllFiles 0
-#define kVLCLibraryModeAllAlbums 1
-#define kVLCLibraryModeAllSeries 2
+typedef enum {
+    VLCLibraryModeAllFiles  = 0,
+    VLCLibraryModeAllAlbums = 1,
+    VLCLibraryModeAllSeries = 2
+} VLCLibraryMode;
 
 @class VLCMovieViewController;
 @class EmptyLibraryView;
+@class AQGridView;
 
 @interface VLCPlaylistViewController : UIViewController <UITabBarDelegate, UIPopoverControllerDelegate>
 
 @property (nonatomic, strong) VLCMovieViewController *movieViewController;
 @property (nonatomic, strong) UIViewController *menuViewController;
-@property (nonatomic, strong) UIPopoverController *addMediaPopoverController;
-
-@property (nonatomic, strong) UITableView *tableView;
-@property (nonatomic, strong) AQGridView *gridView;
-
-@property (nonatomic, strong) EmptyLibraryView *emptyLibraryView;
 
 - (IBAction)leftButtonAction:(id)sender;
 
@@ -37,7 +33,7 @@
 - (void)openMovieFromURL:(NSURL *)url;
 - (void)removeMediaObject:(MLFile *)mediaObject;
 
-- (void)setLibraryMode:(NSUInteger)mode;
+- (void)setLibraryMode:(VLCLibraryMode)mode;
 
 @end
 
